<div align="center">
   <img src="OpenNano.png",
   height=300>
</div>

## Open Nano

Open Nano is a free open source python package developed to address a lack of python-based tools for analysing Nanostring GeoMx DSP data.

From your dcc, pkc, and metadata files, you can:
-  create an AnnData object of your data 
-  perform quality control and normalisation steps
-  do a differential gene expression analysis
-  look at spatial autocorralation with Moran's I statistic
-  perform UMAP and tSNE clustering

Benchmarked against GeoMxTools R package and DESeq2.

See 

Created by Charalampos Anagostakis, Laura Beltrame, Cristiano Cordì, and Niamh Callian Keenan
as part of the Integrated Bioinformatics Project for the MSc in Bioinformatics at KU Leuven, Belgium
